Module agent_loop

Module agent_loop 

Agent loop – the main request/response cycle driver. Agent loop — the main request/response cycle driver.

Coordinates the interaction between the agent, provider, tools, and state management. Handles streaming, tool execution, retry logic, and compaction events.

Re-exports

pub use config::AfterToolCallHook;
pub use config::AgentLoopConfig;
pub use config::BeforeToolCallHook;
pub use config::ToolExecutionMode;

Modules

config
Agent-loop configuration. Agent loop configuration types
helpers
Miscellaneous helper functions.
queues
Internal message/event queues. Queue management for agent loop
retry
Retry logic for the agent loop.
streaming
Streaming response handling.
tool_exec
Tool execution strategies.

Structs

AgentLoop
AgentLoop.