pub fn compute_edits_diff(
original: &str,
modified: &str,
context_lines: usize,
) -> EditDiffResultExpand description
Compute a unified diff between original and modified content. Returns the diff string and the first changed line number.