pub struct EditDiffResult {
pub diff: String,
pub first_changed_line: Option<usize>,
}Expand description
Result of computing diffs for a set of edits
Fields
diff: StringThe unified diff string
first_changed_line: Option<usize>Line number of the first change in the new file (for editor navigation)