pub struct SearchCache { /* private fields */ }Expand description
In-memory cache for search results, keyed by search ID.
Implementations
Sourceimpl SearchCache
impl SearchCache
Sourcepub fn with_capacity(max_entries: usize) -> Self
pub fn with_capacity(max_entries: usize) -> Self
Create a new cache with the given maximum capacity.